package org.greenstone.gsdl3.util;

// XML classes
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;

import javax.xml.transform.stream.StreamSource;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

// other java classes
import java.io.StringReader;
import java.io.StringWriter;

/** XMLConverter - utitlity class for greenstone
 *
 * parses XML Strings into Documents, converts Nodes to Strings
 * different parsers have different behaviour - can experiment in here
 *
 */
public class XMLTransformer {

    TransformerFactory t_factory_=null;
    
    public XMLTransformer() {
	try {
	    t_factory_ = TransformerFactory.newInstance();

	} catch (Exception e) {
	    System.out.println("XMLTransformer() exception "+e.getMessage());
	}
    }

 
	
    public String transform(String stylesheet, String xml_in) {
	
	try {
	    // Use the TransformerFactory to process the stylesheet Source and generate a Transformer.
	    Transformer transformer = t_factory_.newTransformer(new StreamSource(stylesheet));

	    // Use the Transformer to transform an XML Source and send the output to a Result object.
	    StringWriter output = new StringWriter();

	    transformer.transform(new StreamSource(new StringReader(xml_in)), new StreamResult(output));
	    return output.toString();
	} catch (TransformerConfigurationException e) {
	    System.err.println("XMLTransformer: couldn't create transformer object");
	    return "";
	} catch (TransformerException e) {
	    System.err.println("XMLTransformer: couldn't transform the source");
	    return "";
	}	
    }
}

 
